/*
 *	osexec
 *
 *    Copyright (C) 2000-2004 GFD Dennou Club. All rights reserved.
 *
 */

#include <stdlib.h>
#include <string.h>

void osexec_(char *cmd, int Lcmd)
{
    int nc;
    char cmdx[80];

    memcpy (cmdx, cmd, Lcmd);
    for (nc = Lcmd; nc > 0; --nc)
	if (*(cmd + nc - 1) != '\0' && *(cmd + nc - 1) != ' ')
	    break;
    cmdx[nc] = '\0';
    system (cmdx);
}
